Files
TheRock/compiler/amd-llvm/clang/test/SemaCUDA/exceptions.cu
T
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

56 lines
1.5 KiB
Plaintext

// RUN: %clang_cc1 -fcxx-exceptions -fcuda-is-device -fsyntax-only -verify %s
// RUN: %clang_cc1 -fcxx-exceptions -fsyntax-only -verify %s
#include "Inputs/cuda.h"
void host() {
throw NULL;
try {} catch(void*) {}
}
__device__ void device() {
throw NULL;
// expected-error@-1 {{cannot use 'throw' in __device__ function}}
try {} catch(void*) {}
// expected-error@-1 {{cannot use 'try' in __device__ function}}
}
__global__ void kernel() {
throw NULL;
// expected-error@-1 {{cannot use 'throw' in __global__ function}}
try {} catch(void*) {}
// expected-error@-1 {{cannot use 'try' in __global__ function}}
}
// Check that it's an error to use 'try' and 'throw' from a __host__ __device__
// function if and only if it's codegen'ed for device.
__host__ __device__ void hd1() {
throw NULL;
try {} catch(void*) {}
#ifdef __CUDA_ARCH__
// expected-error@-3 {{cannot use 'throw' in __host__ __device__ function}}
// expected-error@-3 {{cannot use 'try' in __host__ __device__ function}}
#endif
}
// No error, never instantiated on device.
inline __host__ __device__ void hd2() {
throw NULL;
try {} catch(void*) {}
}
void call_hd2() { hd2(); }
// Error, instantiated on device.
inline __host__ __device__ void hd3() {
throw NULL;
try {} catch(void*) {}
#ifdef __CUDA_ARCH__
// expected-error@-3 {{cannot use 'throw' in __host__ __device__ function}}
// expected-error@-3 {{cannot use 'try' in __host__ __device__ function}}
#endif
}
__device__ void call_hd3() { hd3(); }
#ifdef __CUDA_ARCH__
// expected-note@-2 {{called by 'call_hd3'}}
#endif